# -*- coding: utf-8 -*-

__title__ = "drf-friendly-errors"
__version__ = "0.14.6"
__author__ = "Tomasz Łaszczuk(Original), Mrityunjay Saxena(This fork)"
__contact__ = "mrityunjay.saxena@egyanamtech.com"
__license__ = "MIT"


# Version synonym
VERSION = __version__
